pub enum PixelMode {
Normal,
Alpha,
Mask,
}Expand description
The Drawing Mode used
Variants
Normal
Basic drawing mode The pixel data after the draw will be the same as the pixel given
Alpha
Using Alpha in the Draw, Will be more computaion heavy You should only activate when you need the alpha blending and then change it back
Mask
Will draw only if the alpha is equals to 255